// (c) Copyright Open Text Corporation

package com.opentext.livelink.service.hello;

import java.io.*;
import java.util.Date;

import javax.xml.bind.annotation.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.opentext.api.*;
import com.opentext.livelink.service.core.*;

/**
 * HelloGreeting is a sample SDO that holds a friendly greeting.
 * @version 2013-08-27
 */
@XmlAccessorType( XmlAccessType.PROPERTY )
@XmlType( name = "HelloGreeting", namespace = "urn:Hello.service.livelink.opentext.com", propOrder = {
	"greetingDate",
	"greetingMessage"
} )
public class HelloGreeting
	extends ServiceDataObject
	implements Serializable
{
	private static final long serialVersionUID = 20130827L;
	private static Log sLog = LogFactory.getLog( "com.opentext.livelink.service.hello.HelloGreeting" );
	private Date fGreetingDate;
	private String fGreetingMessage;

	/**
	 * Sets the Date of the greeting.
	 */
	@XmlElement( name = "GreetingDate", namespace = "urn:Hello.service.livelink.opentext.com", nillable = false )
	public void setGreetingDate( Date value )
	{
		fGreetingDate = value;
	}

	/**
	 * Gets the Date of the greeting.
	 */
	public Date getGreetingDate()
	{
		return fGreetingDate;
	}

	/**
	 * Sets the greeting message.
	 */
	@XmlElement( name = "GreetingMessage", namespace = "urn:Hello.service.livelink.opentext.com", nillable = false )
	public void setGreetingMessage( String value )
	{
		fGreetingMessage = value;
	}

	/**
	 * Gets the greeting message.
	 */
	public String getGreetingMessage()
	{
		return fGreetingMessage;
	}

	public  void load( LLValue value )
	{
		String		featureName = null;

		// Load the parent
		super.load( value );

		try
		{

			featureName = "GreetingDate";
			fGreetingDate = SDOUtil.getDateValue( value.toValue( "GreetingDate" ), "GreetingDate" );

			featureName = "GreetingMessage";
			fGreetingMessage = SDOUtil.getStringValue( value.toValue( "GreetingMessage" ), "GreetingMessage" );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error loading HelloGreeting." + featureName;
			sLog.error( errMsg );
			sLog.error( "  LAPI error: " + ex.getMessage(), ex );
			throw new ServiceException( errMsg );
		}
		catch ( ServiceException ex )
		{
			String		errMsg = "Error loading HelloGreeting." + featureName;
			sLog.error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
		catch ( Exception ex )
		{
			String		errMsg = "Error loading HelloGreeting." + featureName;
			sLog.error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
	}

	public  LLValue toLLValue()
	{
		LLValue		value = new LLValue();

		value.setAssoc();

		try
		{
			SDOUtil.setPrimitiveValue( value, "GreetingDate", fGreetingDate, LLValue.LL_DATE );
			SDOUtil.setPrimitiveValue( value, "GreetingMessage", fGreetingMessage, LLValue.LL_STRING );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error converting HelloGreeting to an LLValue";
			sLog.error( errMsg );
			sLog.error( "  LAPI error: " + ex.getMessage(), ex );
			throw new ServiceException( errMsg );
		}

		LLValue	parent = super.toLLValue();

		if ( parent != null )
		{
			LLNameEnumeration nameEnum = parent.enumerateNames();
			while ( nameEnum.hasMoreElements() )
			{
				String	name = nameEnum.nextName();
				value.add( name, parent.toValue( name ) );
			}
		}

		// override any _SDOName set in the parent
		value.add( "_SDOName", "Hello.HelloGreeting" );

		return value;
	}

	public String toString()
	{
		StringBuffer	sb = new StringBuffer();
		sb.append( "HelloGreeting[" );
		sb.append( "fGreetingDate=" ).append( fGreetingDate ).append( ",");
		sb.append( "fGreetingMessage=" ).append( fGreetingMessage ).append( ",");
		sb.append( "]" );
		// Output the parent
		sb.append( super.toString() );
		return sb.toString();
	}
}
