// (c) Copyright Open Text Corporation

package com.opentext.livelink.service.hello;

import java.io.*;

import javax.xml.bind.annotation.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.opentext.api.*;
import com.opentext.livelink.service.core.*;

/**
 * HelloMessage encapsulates the message returned from the HelloWorld service.
 * @version 2013-08-27
 */
@XmlAccessorType( XmlAccessType.PROPERTY )
@XmlType( name = "HelloMessage", namespace = "urn:Hello.service.livelink.opentext.com", propOrder = {
	"greeting",
	"message",
	"messageList",
	"numberOfMessages"
} )
public class HelloMessage
	extends ServiceDataObject
	implements Serializable
{
	private static final long serialVersionUID = 20130827L;
	private static Log sLog = LogFactory.getLog( "com.opentext.livelink.service.hello.HelloMessage" );
	private HelloGreeting fGreeting;
	private String fMessage;
	private String[] fMessageList;
	private int fNumberOfMessages;

	/**
	 * Sets the HelloGreeting object.
	 */
	@XmlElement( name = "Greeting", namespace = "urn:Hello.service.livelink.opentext.com", nillable = false )
	public void setGreeting( HelloGreeting value )
	{
		fGreeting = value;
	}

	/**
	 * Gets the HelloGreeting object.
	 */
	public HelloGreeting getGreeting()
	{
		return fGreeting;
	}

	/**
	 * Sets the message.
	 */
	@XmlElement( name = "Message", namespace = "urn:Hello.service.livelink.opentext.com", nillable = false )
	public void setMessage( String value )
	{
		fMessage = value;
	}

	/**
	 * Gets the message.
	 */
	public String getMessage()
	{
		return fMessage;
	}

	/**
	 * Sets the list of messages.
	 */
	@XmlElement( name = "MessageList", namespace = "urn:Hello.service.livelink.opentext.com", nillable = false )
	public void setMessageList( String[] value )
	{
		fMessageList = value;
	}

	/**
	 * Gets the list of messages.
	 */
	public String[] getMessageList()
	{
		return fMessageList;
	}

	/**
	 * Sets the value at the specified index in the fMessageList array.
	 */
	public void setMessageList( int index, String value )
	{
		fMessageList[ index ] = value;
	}

	/**
	 * Gets the value at the specified index in the MessageList array.
	 */
	public String getMessageList( int index )
	{
		return fMessageList[ index ];
	}

	/**
	 * Sets the number of messages.
	 */
	@XmlElement( name = "NumberOfMessages", namespace = "urn:Hello.service.livelink.opentext.com", nillable = false )
	public void setNumberOfMessages( int value )
	{
		fNumberOfMessages = value;
	}

	/**
	 * Gets the number of messages.
	 */
	public int getNumberOfMessages()
	{
		return fNumberOfMessages;
	}

	public  void load( LLValue value )
	{
		String		featureName = null;

		// Load the parent
		super.load( value );

		try
		{

			featureName = "Greeting";
			fGreeting = (HelloGreeting) SDOUtil.getSDOValue( "com.opentext.livelink.service.hello", value.toValue( "Greeting" ) );

			featureName = "Message";
			fMessage = SDOUtil.getStringValue( value.toValue( "Message" ), "Message" );

			featureName = "MessageList";
			LLValue				list = new LLValue();


			list = value.toValue( "MessageList" );
			if ( list.isDefined() )
			{
				fMessageList = new String[ SDOUtil.getSize( list ) ];
				SDOUtil.loadStringList( fMessageList, list );
			}

			featureName = "NumberOfMessages";
			fNumberOfMessages = SDOUtil.getIntegerValue( value.toValue( "NumberOfMessages" ), "NumberOfMessages" );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error loading HelloMessage." + featureName;
			sLog.error( errMsg );
			sLog.error( "  LAPI error: " + ex.getMessage(), ex );
			throw new ServiceException( errMsg );
		}
		catch ( ServiceException ex )
		{
			String		errMsg = "Error loading HelloMessage." + featureName;
			sLog.error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
		catch ( Exception ex )
		{
			String		errMsg = "Error loading HelloMessage." + featureName;
			sLog.error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
	}

	public  LLValue toLLValue()
	{
		LLValue		value = new LLValue();

		value.setAssoc();

		try
		{
			SDOUtil.setSDOValue( value, "Greeting", fGreeting );
			SDOUtil.setPrimitiveValue( value, "Message", fMessage, LLValue.LL_STRING );
			SDOUtil.setPrimitiveList( value, "MessageList", fMessageList, LLValue.LL_STRING );
			SDOUtil.setPrimitiveValue( value, "NumberOfMessages", fNumberOfMessages, LLValue.LL_INTEGER );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error converting HelloMessage to an LLValue";
			sLog.error( errMsg );
			sLog.error( "  LAPI error: " + ex.getMessage(), ex );
			throw new ServiceException( errMsg );
		}

		LLValue	parent = super.toLLValue();

		if ( parent != null )
		{
			LLNameEnumeration nameEnum = parent.enumerateNames();
			while ( nameEnum.hasMoreElements() )
			{
				String	name = nameEnum.nextName();
				value.add( name, parent.toValue( name ) );
			}
		}

		// override any _SDOName set in the parent
		value.add( "_SDOName", "Hello.HelloMessage" );

		return value;
	}

	public String toString()
	{
		StringBuffer	sb = new StringBuffer();
		sb.append( "HelloMessage[" );
		sb.append( "fGreeting=" ).append( fGreeting ).append( ",");
		sb.append( "fMessage=" ).append( fMessage ).append( ",");
		sb.append( "fMessageList=" ).append( fMessageList ).append( ",");
		sb.append( "fNumberOfMessages=" ).append( fNumberOfMessages ).append( ",");
		sb.append( "]" );
		// Output the parent
		sb.append( super.toString() );
		return sb.toString();
	}
}
